"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var react_1 = tslib_1.__importStar(require("react"));
var classnames_1 = tslib_1.__importDefault(require("classnames"));
var use_ref_and_forward_1 = require("../_util/use-ref-and-forward");
var controlled_1 = require("../form/controlled");
var tooltip_1 = require("../tooltip");
var call_both_1 = require("../_util/call-both");
/**
 * Check 组件支持使用 CheckContext 进行状态托管
 */
exports.CheckContext = react_1.default.createContext(null);
exports.Check = react_1.forwardRef(function (_props, ref) {
    // 支持从 Context 注入
    var context = react_1.useContext(exports.CheckContext);
    var props = _props;
    if (context) {
        props = context.inject(_props);
    }
    var _a = controlled_1.useDefaultValue(props, false), value = _a.value, onChange = _a.onChange, type = _a.type, indeterminate = _a.indeterminate, children = _a.children, className = _a.className, _b = _a.disabled, disabled = _b === void 0 ? false : _b, onClick = _a.onClick, display = _a.display, style = _a.style, inputRef = _a.inputRef, tooltip = _a.tooltip, htmlProps = tslib_1.__rest(_a, ["value", "onChange", "type", "indeterminate", "children", "className", "disabled", "onClick", "display", "style", "inputRef", "tooltip"]);
    // handle indeterminate
    var _c = tslib_1.__read(use_ref_and_forward_1.useRefAndForward(null, inputRef), 2), checkInputRef = _c[0], forwardInputRef = _c[1];
    react_1.useEffect(function () {
        if (type === "checkbox" && checkInputRef.current) {
            checkInputRef.current.indeterminate = indeterminate;
        }
    });
    var labelClassName = classnames_1.default("tea-form-check", {
        "tea-form-check--block": display === "block",
    }, className);
    var check = (react_1.default.createElement("label", tslib_1.__assign({ ref: ref, className: labelClassName, style: style }, htmlProps, { onClick: function (event) { return event.stopPropagation(); } }),
        react_1.default.createElement("input", { readOnly: true, ref: forwardInputRef, type: type, className: "tea-" + type, checked: value, disabled: disabled, onClick: call_both_1.callBoth(onClick, function (event) {
                return onChange(event.currentTarget.checked, {
                    event: event,
                    check: tslib_1.__assign({}, props, { value: event.currentTarget.checked }),
                });
            }) }),
        react_1.default.createElement("span", { key: "label", className: "tea-form-check__label" }, children)));
    if (tooltip) {
        check = react_1.default.createElement(tooltip_1.Tooltip, { title: tooltip }, check);
    }
    return check;
});
exports.Check.displayName = "Check";
//# sourceMappingURL=Check.js.map