import React from "react";
import { TableAddon } from "../TableProps";
import { StatusTipProps } from "../../tips";
import { FetcherState, QueryState, Omit } from "../../_type";
/**
 * `autotip` 插件用于给定表格数据的状态，自动提供合适的 `topTip` 来显示该状态。
```jsx
import { autotip } from '@tea/component/table/addons/autotip';
function Example() {
  return <Table addons={[autotip(options)]} />;
}
```
 */
export interface AutoTipOptions extends Omit<StatusTipProps, "status"> {
    /**
     * 数据是否在加载中
     */
    isLoading?: boolean;
    /**
     * 数据加载是否异常
     */
    isError?: boolean;
    /**
     * 数据是否被筛选
     */
    isFound?: boolean;
    /**
     * 用于没有传入 `foundText` 时，默认筛选文案的生成
     *
     * 如果提供了 `foundKeyword`，默认筛选文案将会使用
     */
    foundKeyword?: string;
    /**
     * 用于没有传入 `foundText` 时，默认筛选文案的生成
     *
     * 如果提供了 `foundCount`，默认筛选文案将会使用，不提供时将使用当前传入的记录条数
     *
     * `foundCount` 为 0 时将使用空数据提示文案
     */
    foundCount?: number;
}
/**
 * 给定表格数据的状态，自动提供合适的 topTip 来显示该状态
 */
export declare function autotip(options: AutoTipOptions): TableAddon;
export declare namespace autotip {
    var fromLegacyState: ({ enableLoading, fetcher, query, onClearSearch, onRetry, emptyTips, }: LegacySmartTipState) => TableAddon<any>;
}
export interface LegacySmartTipState {
    fetcher: FetcherState<any>;
    query?: QueryState<any>;
    onClearSearch?: () => void;
    onRetry?: () => void;
    emptyTips?: React.ReactNode;
    enableLoading?: boolean;
}
