import React from "react";
import { TableAddon, RowRenderContext } from "../TableProps";
import { ControlledProps } from "../../form/controlled";
/**
 * `radioable` 插件用于支持表格可单选行的样式及操作。
```jsx
import { radioable } from '@tea/component/table/addons/radioable';
function Example() {
  return <Table addons={[radioable(options)]} />;
}
```
 */
export interface RadioableOptions<Record = any> extends ControlledProps<string, React.SyntheticEvent, {
    event: React.SyntheticEvent;
    record: Record;
}> {
    /**
     * 不支持非受控模式
     */
    defaultValue?: never;
    /**
     * 提供一个列的 `key`，将选择组件插入到一个目标列
     *
     * 默认在最前新建一列插入
     */
    targetColumnKey?: string;
    /**
     * 是否整行可选
     * @default false
     */
    rowSelect?: boolean;
    /**
     * 列宽度，可以指定 CSS 属性或数字 (单位：px)
     * @default 26
     */
    width?: string | number;
    /**
     * **高级用法**
     * 更改该插件的在每行的渲染内容，`element` 为默认渲染内容，`context` 中包含该行数据相关信息
     * @default x => x
     */
    render?: (element: JSX.Element, context: RowRenderContext<Record>) => React.ReactNode;
}
export declare function radioable({ value, onChange, targetColumnKey, rowSelect, width, render, }: RadioableOptions): TableAddon;
