import React from "react";
import classNames from "classnames";
import { StyledProps } from "../_type";

export interface BadgeProps extends StyledProps {
  /**
   * 颜色主题
   *
   * @default "default"
   */
  theme?: "default" | "success" | "warning" | "danger";

  /**
   * 是否为深色背景
   *
   * @default false
   */
  dark?: boolean;

  /**
   * 徽章中内容
   */
  children?: React.ReactNode;
}

export function Badge({
  theme = "default",
  dark,
  children,
  className,
  style,
}: BadgeProps) {
  const classSuffix = dark ? "-dark" : "";
  return (
    <span
      className={classNames("tea-badge", className, {
        [`is-blue${classSuffix}`]: theme === "default",
        [`is-success${classSuffix}`]: theme === "success",
        [`is-warning${classSuffix}`]: theme === "warning",
        [`is-error${classSuffix}`]: theme === "danger",
      })}
      style={style}
    >
      {children}
    </span>
  );
}
