import React from "react";
import classNames from "classnames";
import { ControlledProps, useDefaultValue } from "../form/controlled";
import { Combine, StyledProps } from "../_type";
import { Button } from "../button";
import { SegmentOption } from "./SegmentOption";
import { Bubble } from "../bubble";

export interface SegmentProps
  extends Combine<StyledProps, ControlledProps<string>> {
  /**
   * Segment 中选项
   */
  options: SegmentOption[];

  /**
   * 是否为无边框样式
   * @default false
   */
  rimless?: boolean;
}

export function Segment(props: SegmentProps) {
  const {
    className,
    style,
    value,
    onChange,
    options,
    rimless,
  } = useDefaultValue(props, "");

  return (
    <div
      className={classNames("tea-segment", className, {
        "tea-segment--rimless": rimless,
      })}
      style={style}
    >
      {options.map(option => {
        const button = (
          <Button
            key={option.value}
            disabled={option.disabled}
            tooltip={option.tooltip}
            htmlType="button"
            className={classNames({
              "is-selected": option.value === value,
            })}
            onClick={
              option.disabled
                ? null
                : event => {
                    onChange(option.value, { event });
                  }
            }
          >
            {option.text || option.value}
          </Button>
        );
        if (option.bubble) {
          return (
            <Bubble key={option.value} content={option.bubble}>
              {button}
            </Bubble>
          );
        }
        return button;
      })}
    </div>
  );
}

Segment.defaultLabelAlign = "middle";
