import React from "react";
import classNames from "classnames";
import { Icon } from "../icon";
import { StyledProps } from "../_type";

export interface TagProps extends StyledProps {
  /**
   * 标签内容
   */
  children: React.ReactNode;

  /**
   * 关闭时回调
   *
   * **传递该参数时将展示关闭按钮**
   */
  onClose?: (event: React.MouseEvent) => void;
}

export function Tag({ children, onClose, className, style }: TagProps) {
  const hasCloseHandler = typeof onClose === "function";
  return (
    <div
      className={classNames("tea-tag", className, {
        "tea-tag--edit": hasCloseHandler,
      })}
      style={style}
    >
      <span>{children}</span>
      {hasCloseHandler && <Icon link type="dismiss" onClick={onClose} />}
    </div>
  );
}
