import React from "react";
import classNames from "classnames";
import { Icon } from "../icon";
import { Text } from "../text";
import { useTranslation } from "../i18n";
import { StyledProps } from "../_type";

export interface ErrorTipProps extends StyledProps {
  /**
   * 错误文案
   * @default "加载失败"
   */
  errorText?: React.ReactNode;

  /**
   * 重试文案
   * @default "重试"
   */
  retryText?: React.ReactNode;

  /**
   * 重试时回调，如果传空，则不进行重试
   */
  onRetry?: () => void;
}

export function ErrorTip({
  errorText,
  onRetry,
  retryText,
  className,
  style,
}: ErrorTipProps) {
  const t = useTranslation();
  const text = errorText || t.loadErrorText;
  return (
    <span className={classNames("tea-action-state", className)} style={style}>
      <Icon type="error" className="tea-mr-2n" />
      {typeof text === "string" ? (
        <Text className="tea-action-state__text" theme="danger">
          {text}
        </Text>
      ) : (
        text
      )}
      {onRetry && (
        <>
          {" "}
          <a
            href="javascript:;"
            className="tea-action-state__text"
            onClick={onRetry}
          >
            {retryText || t.loadRetryText}
          </a>
        </>
      )}
    </span>
  );
}
