import { Scale } from "./context";
import { ChartProps, Tooltip as TooltipCfg, Legend as LegendCfg } from "../type";
import { Line, Bar } from "./shape";
export declare class Chart {
    /**
     * 全局上下文
     */
    private ctx;
    /**
     * 直角坐标系
     */
    private rectCoordinate;
    /**
     * 图形实例
     */
    private shapes;
    /**
     * 事件层实例
     */
    private event;
    /**
     * 提示框实例
     */
    private tooltipInstance;
    /**
     * 图例实例
     */
    private legendInstance;
    /**
     * Resize 的缓冲器
     */
    private resizeTimer;
    constructor(root: HTMLElement);
    /**
     * 设置数据源，转化为标准数据对象 MetaData
     * @param dataSource 原始数据源
     * @param scaleConfig 列定义设置
     */
    source(dataSource: ChartProps["dataSource"]): this;
    /**
     * 设置数据源的列
     * @param scale 列定义
     */
    scale(scale: Scale): this;
    /**
     * 设置提示框
     * @param enable 是否显示提示框
     * @param tooltipCfg 提示框配置
     */
    tooltip(enable: boolean | TooltipCfg, tooltipCfg?: TooltipCfg): this;
    /**
     * 设置图例
     * @param enable 是否显示图例
     * @param legendCfg 图例配置
     */
    legend(enable: boolean | LegendCfg, legendCfg?: LegendCfg): this;
    /**
     * 创建折线图实例
     */
    line(): Line;
    bar(): Bar;
    /**
     * 开始渲染
     */
    render(): void;
    /**
     * 重置尺寸
     */
    resize(): void;
    /**
     * 销毁图表实例
     */
    destroy(): void;
}
