"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var react_1 = tslib_1.__importStar(require("react"));
var react_dom_1 = tslib_1.__importDefault(require("react-dom"));
var ModalMain_1 = require("./ModalMain");
var button_1 = require("../button");
var ModalMessage_1 = require("./ModalMessage");
var i18n_1 = require("../i18n");
/**
 * API 的方式唤起一个确认对话框
 * @param options
 * @returns 异步返回布尔值，为 true 则表示用户确认，为 false 则表示用户取消
 */
function confirm(options) {
    return new Promise(function (resolve) {
        var el = document.createElement("div");
        react_dom_1.default.render(react_1.default.createElement(ModalConfirmAPI, tslib_1.__assign({}, options, { onOk: function () { return resolve(true); }, onCancel: function () { return resolve(false); }, onExited: function () {
                react_dom_1.default.unmountComponentAtNode(el);
            } })), el);
    });
}
exports.confirm = confirm;
function ModalConfirmAPI(_a) {
    var onOk = _a.onOk, onCancel = _a.onCancel, confirmModalProps = tslib_1.__rest(_a, ["onOk", "onCancel"]);
    var _b = tslib_1.__read(react_1.useState(false), 2), visible = _b[0], setVisible = _b[1];
    // 渲染之后，马上显示
    react_1.useEffect(function () { return setVisible(true); }, []);
    var ok = function () {
        setVisible(false);
        onOk();
    };
    var cancel = function () {
        setVisible(false);
        onCancel();
    };
    return (react_1.default.createElement(ModalConfirm, tslib_1.__assign({ visible: visible, onOk: ok, onCancel: cancel, onClose: cancel }, confirmModalProps)));
}
/**
 * 提供原始的 ModalConfirm 组件。
 * 推荐使用 `Modal.confirm()` API 来简化用法
 */
function ModalConfirm(_a) {
    var message = _a.message, description = _a.description, modalProps = tslib_1.__rest(_a, ["message", "description"]);
    react_1.useEffect(function () {
        window.focus();
    }, []);
    return (react_1.default.createElement(ModalMain_1.Modal, tslib_1.__assign({ disableEscape: true }, modalProps),
        react_1.default.createElement(ModalMain_1.Modal.Body, null,
            react_1.default.createElement(ModalMessage_1.ModalMessage, { message: message, description: description })),
        react_1.default.createElement(ModalMain_1.Modal.Footer, null,
            react_1.default.createElement(ModalButton, tslib_1.__assign({}, modalProps)))));
}
exports.ModalConfirm = ModalConfirm;
function ModalButton(_a) {
    var onOk = _a.onOk, okText = _a.okText, onCancel = _a.onCancel, cancelText = _a.cancelText;
    var t = i18n_1.useTranslation();
    var mainButtonRef = react_1.useRef(null);
    react_1.useEffect(function () {
        if (mainButtonRef.current) {
            mainButtonRef.current.focus();
        }
    }, []);
    return (react_1.default.createElement(react_1.default.Fragment, null,
        react_1.default.createElement(button_1.Button, { type: "primary", onClick: onOk, ref: mainButtonRef }, okText || t.okText),
        react_1.default.createElement(button_1.Button, { onClick: onCancel }, cancelText || t.cancelText)));
}
//# sourceMappingURL=ModalConfirm.js.map