import { Moment } from "moment";
import { useOutsideClick } from "../_util/use-outside-click";
import { TriggerProps } from "../popover/trigger";

export function getYearMonthDate(date: Moment) {
  return {
    year: date.year(),
    month: date.month(),
    date: date.date(),
  };
}

export const DatePickerTrigger = ({
  childrenElementRef,
  overlayElementRef,
  visible,
  render,
  onOpen,
  onClose,
}: TriggerProps & { onOpen: () => void; onClose: () => void }) => {
  const { listen } = useOutsideClick([childrenElementRef, overlayElementRef]);

  listen(() => {
    if (visible) {
      onClose();
    }
  });

  return render({
    overlayProps: {},
    childrenProps: {
      onClick: (event: React.MouseEvent) => {
        event.stopPropagation();
        if (!visible) {
          onOpen();
        } else {
          onClose();
        }
      },
    },
  });
};
