import React from "react";
import classNames from "classnames";
import { useTranslation } from "../i18n";
import { StyledProps } from "../_type";

export interface FoundTipProps extends StyledProps {
  /**
   * 找到结果的文案
   * @default "找到下列结果"
   */
  foundText?: React.ReactNode;

  /**
   * 清空结果提示文案
   * @default "返回原列表"
   */
  clearResultText?: React.ReactNode;

  /**
   * 返回原列表时回调，如果不传则不渲染此操作
   */
  onClear?: () => void;
}

export function FoundTip(props: FoundTipProps) {
  const t = useTranslation();
  const {
    foundText = t.foundText,
    clearResultText = t.clearResultText,
    onClear,
    className,
    style,
  } = props;
  return (
    <span className={classNames("tea-action-state", className)} style={style}>
      {typeof foundText === "string" ? (
        <span className="tea-action-state__text">{foundText}</span>
      ) : (
        foundText
      )}
      {onClear && (
        <>
          {" "}
          <a className="tea-action-state__text" onClick={onClear}>
            {clearResultText}
          </a>
        </>
      )}
    </span>
  );
}
