import React, { useState } from "react";
import classNames from "classnames";
import { Upload } from "@tea/component/upload";
import { Button } from "@tea/component/button";
import { Text } from "@tea/component/text";
import { Form } from "@tea/component/form";

export default function SingleFileUploadExample() {
  const [fileList, setFileList] = useState([]);
  const [uploading, setUploading] = useState(null);

  function handleStart() {
    setUploading(true);
  }

  function handleSuccess(result, { file }) {
    setFileList(fileList => [
      ...fileList,
      { name: file.name, status: "success" },
    ]);
    setUploading(false);
    console.log(result);
  }

  function handleError(error, { file }) {
    setFileList(fileList => [
      ...fileList,
      { name: file.name, status: "danger" },
    ]);
    setUploading(false);
    console.error(error);
  }

  return (
    <>
      <Form.Control message="请上传 png 格式文件，大小 1MB 以内">
        <Upload
          action="//jsonplaceholder.typicode.com/posts/"
          accept="image/png"
          maxSize={1024 * 1024}
          multiple
          beforeUpload={(file, fileList, isAccepted) => isAccepted}
          onStart={handleStart}
          onSuccess={handleSuccess}
          onError={handleError}
        >
          {({ open, getDraggerProps, isDragging }) => (
            <div
              className={classNames("tea-form-upload-drag", {
                "tea-form-upload-drag--drag": isDragging,
              })}
            >
              <div
                {...getDraggerProps({ className: "tea-form-upload__inner" })}
              >
                <Text theme="text" className="tea-text__upload-drag" parent="p">
                  <Button type="link" className="tea-btn--file" onClick={open}>
                    <span>点击上传</span>
                  </Button>
                  <Text theme="weak">/拖拽到此区域</Text>
                </Text>
                <Text
                  theme="text"
                  parent="p"
                  className="tea-text__upload-drag tea-text__upload-drag--hover"
                >
                  释放鼠标
                </Text>
              </div>
            </div>
          )}
        </Upload>
      </Form.Control>
      {uploading && <p>正在上传 ...</p>}
      {!!fileList.length && <hr />}
      {fileList.map((file, index) => (
        <p key={index}>
          <Text theme={file.status}>{file.name}</Text>
        </p>
      ))}
    </>
  );
}
