/*
 * Tencent is pleased to support the open source community by making TKEStack
 * available.
 *
 * Copyright (C) 2012-2019 Tencent. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use
 * this file except in compliance with the License. You may obtain a copy of the
 * License at
 *
 * https://opensource.org/licenses/Apache-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OF ANY KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations under the License.
 */

// Code generated by client-gen. DO NOT EDIT.

package internalversion

import (
	"time"

	v1 "k8s.io/apimachinery/pkg/apis/meta/v1"
	types "k8s.io/apimachinery/pkg/types"
	watch "k8s.io/apimachinery/pkg/watch"
	rest "k8s.io/client-go/rest"
	auth "tkestack.io/tke/api/auth"
	scheme "tkestack.io/tke/api/client/clientset/internalversion/scheme"
)

// APISigningKeysGetter has a method to return a APISigningKeyInterface.
// A group's client should implement this interface.
type APISigningKeysGetter interface {
	APISigningKeys() APISigningKeyInterface
}

// APISigningKeyInterface has methods to work with APISigningKey resources.
type APISigningKeyInterface interface {
	Create(*auth.APISigningKey) (*auth.APISigningKey, error)
	Update(*auth.APISigningKey) (*auth.APISigningKey, error)
	Delete(name string, options *v1.DeleteOptions) error
	DeleteCollection(options *v1.DeleteOptions, listOptions v1.ListOptions) error
	Get(name string, options v1.GetOptions) (*auth.APISigningKey, error)
	List(opts v1.ListOptions) (*auth.APISigningKeyList, error)
	Watch(opts v1.ListOptions) (watch.Interface, error)
	Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *auth.APISigningKey, err error)
	APISigningKeyExpansion
}

// aPISigningKeys implements APISigningKeyInterface
type aPISigningKeys struct {
	client rest.Interface
}

// newAPISigningKeys returns a APISigningKeys
func newAPISigningKeys(c *AuthClient) *aPISigningKeys {
	return &aPISigningKeys{
		client: c.RESTClient(),
	}
}

// Get takes name of the aPISigningKey, and returns the corresponding aPISigningKey object, and an error if there is any.
func (c *aPISigningKeys) Get(name string, options v1.GetOptions) (result *auth.APISigningKey, err error) {
	result = &auth.APISigningKey{}
	err = c.client.Get().
		Resource("apisigningkeys").
		Name(name).
		VersionedParams(&options, scheme.ParameterCodec).
		Do().
		Into(result)
	return
}

// List takes label and field selectors, and returns the list of APISigningKeys that match those selectors.
func (c *aPISigningKeys) List(opts v1.ListOptions) (result *auth.APISigningKeyList, err error) {
	var timeout time.Duration
	if opts.TimeoutSeconds != nil {
		timeout = time.Duration(*opts.TimeoutSeconds) * time.Second
	}
	result = &auth.APISigningKeyList{}
	err = c.client.Get().
		Resource("apisigningkeys").
		VersionedParams(&opts, scheme.ParameterCodec).
		Timeout(timeout).
		Do().
		Into(result)
	return
}

// Watch returns a watch.Interface that watches the requested aPISigningKeys.
func (c *aPISigningKeys) Watch(opts v1.ListOptions) (watch.Interface, error) {
	var timeout time.Duration
	if opts.TimeoutSeconds != nil {
		timeout = time.Duration(*opts.TimeoutSeconds) * time.Second
	}
	opts.Watch = true
	return c.client.Get().
		Resource("apisigningkeys").
		VersionedParams(&opts, scheme.ParameterCodec).
		Timeout(timeout).
		Watch()
}

// Create takes the representation of a aPISigningKey and creates it.  Returns the server's representation of the aPISigningKey, and an error, if there is any.
func (c *aPISigningKeys) Create(aPISigningKey *auth.APISigningKey) (result *auth.APISigningKey, err error) {
	result = &auth.APISigningKey{}
	err = c.client.Post().
		Resource("apisigningkeys").
		Body(aPISigningKey).
		Do().
		Into(result)
	return
}

// Update takes the representation of a aPISigningKey and updates it. Returns the server's representation of the aPISigningKey, and an error, if there is any.
func (c *aPISigningKeys) Update(aPISigningKey *auth.APISigningKey) (result *auth.APISigningKey, err error) {
	result = &auth.APISigningKey{}
	err = c.client.Put().
		Resource("apisigningkeys").
		Name(aPISigningKey.Name).
		Body(aPISigningKey).
		Do().
		Into(result)
	return
}

// Delete takes name of the aPISigningKey and deletes it. Returns an error if one occurs.
func (c *aPISigningKeys) Delete(name string, options *v1.DeleteOptions) error {
	return c.client.Delete().
		Resource("apisigningkeys").
		Name(name).
		Body(options).
		Do().
		Error()
}

// DeleteCollection deletes a collection of objects.
func (c *aPISigningKeys) DeleteCollection(options *v1.DeleteOptions, listOptions v1.ListOptions) error {
	var timeout time.Duration
	if listOptions.TimeoutSeconds != nil {
		timeout = time.Duration(*listOptions.TimeoutSeconds) * time.Second
	}
	return c.client.Delete().
		Resource("apisigningkeys").
		VersionedParams(&listOptions, scheme.ParameterCodec).
		Timeout(timeout).
		Body(options).
		Do().
		Error()
}

// Patch applies the patch and returns the patched aPISigningKey.
func (c *aPISigningKeys) Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *auth.APISigningKey, err error) {
	result = &auth.APISigningKey{}
	err = c.client.Patch(pt).
		Resource("apisigningkeys").
		SubResource(subresources...).
		Name(name).
		Body(data).
		Do().
		Into(result)
	return
}
