/*
 * Tencent is pleased to support the open source community by making TKEStack
 * available.
 *
 * Copyright (C) 2012-2019 Tencent. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use
 * this file except in compliance with the License. You may obtain a copy of the
 * License at
 *
 * https://opensource.org/licenses/Apache-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OF ANY KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations under the License.
 */

// Code generated by client-gen. DO NOT EDIT.

package internalversion

import (
	"time"

	v1 "k8s.io/apimachinery/pkg/apis/meta/v1"
	types "k8s.io/apimachinery/pkg/types"
	watch "k8s.io/apimachinery/pkg/watch"
	rest "k8s.io/client-go/rest"
	scheme "tkestack.io/tke/api/client/clientset/internalversion/scheme"
	notify "tkestack.io/tke/api/notify"
)

// ChannelsGetter has a method to return a ChannelInterface.
// A group's client should implement this interface.
type ChannelsGetter interface {
	Channels() ChannelInterface
}

// ChannelInterface has methods to work with Channel resources.
type ChannelInterface interface {
	Create(*notify.Channel) (*notify.Channel, error)
	Update(*notify.Channel) (*notify.Channel, error)
	UpdateStatus(*notify.Channel) (*notify.Channel, error)
	Delete(name string, options *v1.DeleteOptions) error
	Get(name string, options v1.GetOptions) (*notify.Channel, error)
	List(opts v1.ListOptions) (*notify.ChannelList, error)
	Watch(opts v1.ListOptions) (watch.Interface, error)
	Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *notify.Channel, err error)
	ChannelExpansion
}

// channels implements ChannelInterface
type channels struct {
	client rest.Interface
}

// newChannels returns a Channels
func newChannels(c *NotifyClient) *channels {
	return &channels{
		client: c.RESTClient(),
	}
}

// Get takes name of the channel, and returns the corresponding channel object, and an error if there is any.
func (c *channels) Get(name string, options v1.GetOptions) (result *notify.Channel, err error) {
	result = &notify.Channel{}
	err = c.client.Get().
		Resource("channels").
		Name(name).
		VersionedParams(&options, scheme.ParameterCodec).
		Do().
		Into(result)
	return
}

// List takes label and field selectors, and returns the list of Channels that match those selectors.
func (c *channels) List(opts v1.ListOptions) (result *notify.ChannelList, err error) {
	var timeout time.Duration
	if opts.TimeoutSeconds != nil {
		timeout = time.Duration(*opts.TimeoutSeconds) * time.Second
	}
	result = &notify.ChannelList{}
	err = c.client.Get().
		Resource("channels").
		VersionedParams(&opts, scheme.ParameterCodec).
		Timeout(timeout).
		Do().
		Into(result)
	return
}

// Watch returns a watch.Interface that watches the requested channels.
func (c *channels) Watch(opts v1.ListOptions) (watch.Interface, error) {
	var timeout time.Duration
	if opts.TimeoutSeconds != nil {
		timeout = time.Duration(*opts.TimeoutSeconds) * time.Second
	}
	opts.Watch = true
	return c.client.Get().
		Resource("channels").
		VersionedParams(&opts, scheme.ParameterCodec).
		Timeout(timeout).
		Watch()
}

// Create takes the representation of a channel and creates it.  Returns the server's representation of the channel, and an error, if there is any.
func (c *channels) Create(channel *notify.Channel) (result *notify.Channel, err error) {
	result = &notify.Channel{}
	err = c.client.Post().
		Resource("channels").
		Body(channel).
		Do().
		Into(result)
	return
}

// Update takes the representation of a channel and updates it. Returns the server's representation of the channel, and an error, if there is any.
func (c *channels) Update(channel *notify.Channel) (result *notify.Channel, err error) {
	result = &notify.Channel{}
	err = c.client.Put().
		Resource("channels").
		Name(channel.Name).
		Body(channel).
		Do().
		Into(result)
	return
}

// UpdateStatus was generated because the type contains a Status member.
// Add a +genclient:noStatus comment above the type to avoid generating UpdateStatus().

func (c *channels) UpdateStatus(channel *notify.Channel) (result *notify.Channel, err error) {
	result = &notify.Channel{}
	err = c.client.Put().
		Resource("channels").
		Name(channel.Name).
		SubResource("status").
		Body(channel).
		Do().
		Into(result)
	return
}

// Delete takes name of the channel and deletes it. Returns an error if one occurs.
func (c *channels) Delete(name string, options *v1.DeleteOptions) error {
	return c.client.Delete().
		Resource("channels").
		Name(name).
		Body(options).
		Do().
		Error()
}

// Patch applies the patch and returns the patched channel.
func (c *channels) Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *notify.Channel, err error) {
	result = &notify.Channel{}
	err = c.client.Patch(pt).
		Resource("channels").
		SubResource(subresources...).
		Name(name).
		Body(data).
		Do().
		Into(result)
	return
}
