/*
 * Tencent is pleased to support the open source community by making TKEStack
 * available.
 *
 * Copyright (C) 2012-2019 Tencent. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use
 * this file except in compliance with the License. You may obtain a copy of the
 * License at
 *
 * https://opensource.org/licenses/Apache-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OF ANY KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations under the License.
 */

// Code generated by client-gen. DO NOT EDIT.

package internalversion

import (
	"time"

	v1 "k8s.io/apimachinery/pkg/apis/meta/v1"
	types "k8s.io/apimachinery/pkg/types"
	watch "k8s.io/apimachinery/pkg/watch"
	rest "k8s.io/client-go/rest"
	scheme "tkestack.io/tke/api/client/clientset/internalversion/scheme"
	notify "tkestack.io/tke/api/notify"
)

// ReceiversGetter has a method to return a ReceiverInterface.
// A group's client should implement this interface.
type ReceiversGetter interface {
	Receivers() ReceiverInterface
}

// ReceiverInterface has methods to work with Receiver resources.
type ReceiverInterface interface {
	Create(*notify.Receiver) (*notify.Receiver, error)
	Update(*notify.Receiver) (*notify.Receiver, error)
	Delete(name string, options *v1.DeleteOptions) error
	Get(name string, options v1.GetOptions) (*notify.Receiver, error)
	List(opts v1.ListOptions) (*notify.ReceiverList, error)
	Watch(opts v1.ListOptions) (watch.Interface, error)
	Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *notify.Receiver, err error)
	ReceiverExpansion
}

// receivers implements ReceiverInterface
type receivers struct {
	client rest.Interface
}

// newReceivers returns a Receivers
func newReceivers(c *NotifyClient) *receivers {
	return &receivers{
		client: c.RESTClient(),
	}
}

// Get takes name of the receiver, and returns the corresponding receiver object, and an error if there is any.
func (c *receivers) Get(name string, options v1.GetOptions) (result *notify.Receiver, err error) {
	result = &notify.Receiver{}
	err = c.client.Get().
		Resource("receivers").
		Name(name).
		VersionedParams(&options, scheme.ParameterCodec).
		Do().
		Into(result)
	return
}

// List takes label and field selectors, and returns the list of Receivers that match those selectors.
func (c *receivers) List(opts v1.ListOptions) (result *notify.ReceiverList, err error) {
	var timeout time.Duration
	if opts.TimeoutSeconds != nil {
		timeout = time.Duration(*opts.TimeoutSeconds) * time.Second
	}
	result = &notify.ReceiverList{}
	err = c.client.Get().
		Resource("receivers").
		VersionedParams(&opts, scheme.ParameterCodec).
		Timeout(timeout).
		Do().
		Into(result)
	return
}

// Watch returns a watch.Interface that watches the requested receivers.
func (c *receivers) Watch(opts v1.ListOptions) (watch.Interface, error) {
	var timeout time.Duration
	if opts.TimeoutSeconds != nil {
		timeout = time.Duration(*opts.TimeoutSeconds) * time.Second
	}
	opts.Watch = true
	return c.client.Get().
		Resource("receivers").
		VersionedParams(&opts, scheme.ParameterCodec).
		Timeout(timeout).
		Watch()
}

// Create takes the representation of a receiver and creates it.  Returns the server's representation of the receiver, and an error, if there is any.
func (c *receivers) Create(receiver *notify.Receiver) (result *notify.Receiver, err error) {
	result = &notify.Receiver{}
	err = c.client.Post().
		Resource("receivers").
		Body(receiver).
		Do().
		Into(result)
	return
}

// Update takes the representation of a receiver and updates it. Returns the server's representation of the receiver, and an error, if there is any.
func (c *receivers) Update(receiver *notify.Receiver) (result *notify.Receiver, err error) {
	result = &notify.Receiver{}
	err = c.client.Put().
		Resource("receivers").
		Name(receiver.Name).
		Body(receiver).
		Do().
		Into(result)
	return
}

// Delete takes name of the receiver and deletes it. Returns an error if one occurs.
func (c *receivers) Delete(name string, options *v1.DeleteOptions) error {
	return c.client.Delete().
		Resource("receivers").
		Name(name).
		Body(options).
		Do().
		Error()
}

// Patch applies the patch and returns the patched receiver.
func (c *receivers) Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *notify.Receiver, err error) {
	result = &notify.Receiver{}
	err = c.client.Patch(pt).
		Resource("receivers").
		SubResource(subresources...).
		Name(name).
		Body(data).
		Do().
		Into(result)
	return
}
