/*
 * Tencent is pleased to support the open source community by making TKEStack
 * available.
 *
 * Copyright (C) 2012-2019 Tencent. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use
 * this file except in compliance with the License. You may obtain a copy of the
 * License at
 *
 * https://opensource.org/licenses/Apache-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OF ANY KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations under the License.
 */

// Code generated by client-gen. DO NOT EDIT.

package internalversion

import (
	"time"

	v1 "k8s.io/apimachinery/pkg/apis/meta/v1"
	types "k8s.io/apimachinery/pkg/types"
	watch "k8s.io/apimachinery/pkg/watch"
	rest "k8s.io/client-go/rest"
	scheme "tkestack.io/tke/api/client/clientset/internalversion/scheme"
	platform "tkestack.io/tke/api/platform"
)

// ClusterCredentialsGetter has a method to return a ClusterCredentialInterface.
// A group's client should implement this interface.
type ClusterCredentialsGetter interface {
	ClusterCredentials() ClusterCredentialInterface
}

// ClusterCredentialInterface has methods to work with ClusterCredential resources.
type ClusterCredentialInterface interface {
	Create(*platform.ClusterCredential) (*platform.ClusterCredential, error)
	Update(*platform.ClusterCredential) (*platform.ClusterCredential, error)
	Delete(name string, options *v1.DeleteOptions) error
	Get(name string, options v1.GetOptions) (*platform.ClusterCredential, error)
	List(opts v1.ListOptions) (*platform.ClusterCredentialList, error)
	Watch(opts v1.ListOptions) (watch.Interface, error)
	Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *platform.ClusterCredential, err error)
	ClusterCredentialExpansion
}

// clusterCredentials implements ClusterCredentialInterface
type clusterCredentials struct {
	client rest.Interface
}

// newClusterCredentials returns a ClusterCredentials
func newClusterCredentials(c *PlatformClient) *clusterCredentials {
	return &clusterCredentials{
		client: c.RESTClient(),
	}
}

// Get takes name of the clusterCredential, and returns the corresponding clusterCredential object, and an error if there is any.
func (c *clusterCredentials) Get(name string, options v1.GetOptions) (result *platform.ClusterCredential, err error) {
	result = &platform.ClusterCredential{}
	err = c.client.Get().
		Resource("clustercredentials").
		Name(name).
		VersionedParams(&options, scheme.ParameterCodec).
		Do().
		Into(result)
	return
}

// List takes label and field selectors, and returns the list of ClusterCredentials that match those selectors.
func (c *clusterCredentials) List(opts v1.ListOptions) (result *platform.ClusterCredentialList, err error) {
	var timeout time.Duration
	if opts.TimeoutSeconds != nil {
		timeout = time.Duration(*opts.TimeoutSeconds) * time.Second
	}
	result = &platform.ClusterCredentialList{}
	err = c.client.Get().
		Resource("clustercredentials").
		VersionedParams(&opts, scheme.ParameterCodec).
		Timeout(timeout).
		Do().
		Into(result)
	return
}

// Watch returns a watch.Interface that watches the requested clusterCredentials.
func (c *clusterCredentials) Watch(opts v1.ListOptions) (watch.Interface, error) {
	var timeout time.Duration
	if opts.TimeoutSeconds != nil {
		timeout = time.Duration(*opts.TimeoutSeconds) * time.Second
	}
	opts.Watch = true
	return c.client.Get().
		Resource("clustercredentials").
		VersionedParams(&opts, scheme.ParameterCodec).
		Timeout(timeout).
		Watch()
}

// Create takes the representation of a clusterCredential and creates it.  Returns the server's representation of the clusterCredential, and an error, if there is any.
func (c *clusterCredentials) Create(clusterCredential *platform.ClusterCredential) (result *platform.ClusterCredential, err error) {
	result = &platform.ClusterCredential{}
	err = c.client.Post().
		Resource("clustercredentials").
		Body(clusterCredential).
		Do().
		Into(result)
	return
}

// Update takes the representation of a clusterCredential and updates it. Returns the server's representation of the clusterCredential, and an error, if there is any.
func (c *clusterCredentials) Update(clusterCredential *platform.ClusterCredential) (result *platform.ClusterCredential, err error) {
	result = &platform.ClusterCredential{}
	err = c.client.Put().
		Resource("clustercredentials").
		Name(clusterCredential.Name).
		Body(clusterCredential).
		Do().
		Into(result)
	return
}

// Delete takes name of the clusterCredential and deletes it. Returns an error if one occurs.
func (c *clusterCredentials) Delete(name string, options *v1.DeleteOptions) error {
	return c.client.Delete().
		Resource("clustercredentials").
		Name(name).
		Body(options).
		Do().
		Error()
}

// Patch applies the patch and returns the patched clusterCredential.
func (c *clusterCredentials) Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *platform.ClusterCredential, err error) {
	result = &platform.ClusterCredential{}
	err = c.client.Patch(pt).
		Resource("clustercredentials").
		SubResource(subresources...).
		Name(name).
		Body(data).
		Do().
		Into(result)
	return
}
