/*
 * Tencent is pleased to support the open source community by making TKEStack
 * available.
 *
 * Copyright (C) 2012-2019 Tencent. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use
 * this file except in compliance with the License. You may obtain a copy of the
 * License at
 *
 * https://opensource.org/licenses/Apache-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OF ANY KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations under the License.
 */

// Code generated by client-gen. DO NOT EDIT.

package internalversion

import (
	"time"

	v1 "k8s.io/apimachinery/pkg/apis/meta/v1"
	types "k8s.io/apimachinery/pkg/types"
	watch "k8s.io/apimachinery/pkg/watch"
	rest "k8s.io/client-go/rest"
	scheme "tkestack.io/tke/api/client/clientset/internalversion/scheme"
	platform "tkestack.io/tke/api/platform"
)

// GPUManagersGetter has a method to return a GPUManagerInterface.
// A group's client should implement this interface.
type GPUManagersGetter interface {
	GPUManagers() GPUManagerInterface
}

// GPUManagerInterface has methods to work with GPUManager resources.
type GPUManagerInterface interface {
	Create(*platform.GPUManager) (*platform.GPUManager, error)
	Update(*platform.GPUManager) (*platform.GPUManager, error)
	UpdateStatus(*platform.GPUManager) (*platform.GPUManager, error)
	Delete(name string, options *v1.DeleteOptions) error
	Get(name string, options v1.GetOptions) (*platform.GPUManager, error)
	List(opts v1.ListOptions) (*platform.GPUManagerList, error)
	Watch(opts v1.ListOptions) (watch.Interface, error)
	Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *platform.GPUManager, err error)
	GPUManagerExpansion
}

// gPUManagers implements GPUManagerInterface
type gPUManagers struct {
	client rest.Interface
}

// newGPUManagers returns a GPUManagers
func newGPUManagers(c *PlatformClient) *gPUManagers {
	return &gPUManagers{
		client: c.RESTClient(),
	}
}

// Get takes name of the gPUManager, and returns the corresponding gPUManager object, and an error if there is any.
func (c *gPUManagers) Get(name string, options v1.GetOptions) (result *platform.GPUManager, err error) {
	result = &platform.GPUManager{}
	err = c.client.Get().
		Resource("gpumanagers").
		Name(name).
		VersionedParams(&options, scheme.ParameterCodec).
		Do().
		Into(result)
	return
}

// List takes label and field selectors, and returns the list of GPUManagers that match those selectors.
func (c *gPUManagers) List(opts v1.ListOptions) (result *platform.GPUManagerList, err error) {
	var timeout time.Duration
	if opts.TimeoutSeconds != nil {
		timeout = time.Duration(*opts.TimeoutSeconds) * time.Second
	}
	result = &platform.GPUManagerList{}
	err = c.client.Get().
		Resource("gpumanagers").
		VersionedParams(&opts, scheme.ParameterCodec).
		Timeout(timeout).
		Do().
		Into(result)
	return
}

// Watch returns a watch.Interface that watches the requested gPUManagers.
func (c *gPUManagers) Watch(opts v1.ListOptions) (watch.Interface, error) {
	var timeout time.Duration
	if opts.TimeoutSeconds != nil {
		timeout = time.Duration(*opts.TimeoutSeconds) * time.Second
	}
	opts.Watch = true
	return c.client.Get().
		Resource("gpumanagers").
		VersionedParams(&opts, scheme.ParameterCodec).
		Timeout(timeout).
		Watch()
}

// Create takes the representation of a gPUManager and creates it.  Returns the server's representation of the gPUManager, and an error, if there is any.
func (c *gPUManagers) Create(gPUManager *platform.GPUManager) (result *platform.GPUManager, err error) {
	result = &platform.GPUManager{}
	err = c.client.Post().
		Resource("gpumanagers").
		Body(gPUManager).
		Do().
		Into(result)
	return
}

// Update takes the representation of a gPUManager and updates it. Returns the server's representation of the gPUManager, and an error, if there is any.
func (c *gPUManagers) Update(gPUManager *platform.GPUManager) (result *platform.GPUManager, err error) {
	result = &platform.GPUManager{}
	err = c.client.Put().
		Resource("gpumanagers").
		Name(gPUManager.Name).
		Body(gPUManager).
		Do().
		Into(result)
	return
}

// UpdateStatus was generated because the type contains a Status member.
// Add a +genclient:noStatus comment above the type to avoid generating UpdateStatus().

func (c *gPUManagers) UpdateStatus(gPUManager *platform.GPUManager) (result *platform.GPUManager, err error) {
	result = &platform.GPUManager{}
	err = c.client.Put().
		Resource("gpumanagers").
		Name(gPUManager.Name).
		SubResource("status").
		Body(gPUManager).
		Do().
		Into(result)
	return
}

// Delete takes name of the gPUManager and deletes it. Returns an error if one occurs.
func (c *gPUManagers) Delete(name string, options *v1.DeleteOptions) error {
	return c.client.Delete().
		Resource("gpumanagers").
		Name(name).
		Body(options).
		Do().
		Error()
}

// Patch applies the patch and returns the patched gPUManager.
func (c *gPUManagers) Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *platform.GPUManager, err error) {
	result = &platform.GPUManager{}
	err = c.client.Patch(pt).
		Resource("gpumanagers").
		SubResource(subresources...).
		Name(name).
		Body(data).
		Do().
		Into(result)
	return
}
