/*
 * Tencent is pleased to support the open source community by making TKEStack
 * available.
 *
 * Copyright (C) 2012-2019 Tencent. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use
 * this file except in compliance with the License. You may obtain a copy of the
 * License at
 *
 * https://opensource.org/licenses/Apache-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OF ANY KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations under the License.
 */

// Code generated by client-gen. DO NOT EDIT.

package v1

import (
	"time"

	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
	types "k8s.io/apimachinery/pkg/types"
	watch "k8s.io/apimachinery/pkg/watch"
	rest "k8s.io/client-go/rest"
	scheme "tkestack.io/tke/api/client/clientset/versioned/scheme"
	v1 "tkestack.io/tke/api/platform/v1"
)

// VolumeDecoratorsGetter has a method to return a VolumeDecoratorInterface.
// A group's client should implement this interface.
type VolumeDecoratorsGetter interface {
	VolumeDecorators() VolumeDecoratorInterface
}

// VolumeDecoratorInterface has methods to work with VolumeDecorator resources.
type VolumeDecoratorInterface interface {
	Create(*v1.VolumeDecorator) (*v1.VolumeDecorator, error)
	Update(*v1.VolumeDecorator) (*v1.VolumeDecorator, error)
	UpdateStatus(*v1.VolumeDecorator) (*v1.VolumeDecorator, error)
	Delete(name string, options *metav1.DeleteOptions) error
	Get(name string, options metav1.GetOptions) (*v1.VolumeDecorator, error)
	List(opts metav1.ListOptions) (*v1.VolumeDecoratorList, error)
	Watch(opts metav1.ListOptions) (watch.Interface, error)
	Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *v1.VolumeDecorator, err error)
	VolumeDecoratorExpansion
}

// volumeDecorators implements VolumeDecoratorInterface
type volumeDecorators struct {
	client rest.Interface
}

// newVolumeDecorators returns a VolumeDecorators
func newVolumeDecorators(c *PlatformV1Client) *volumeDecorators {
	return &volumeDecorators{
		client: c.RESTClient(),
	}
}

// Get takes name of the volumeDecorator, and returns the corresponding volumeDecorator object, and an error if there is any.
func (c *volumeDecorators) Get(name string, options metav1.GetOptions) (result *v1.VolumeDecorator, err error) {
	result = &v1.VolumeDecorator{}
	err = c.client.Get().
		Resource("volumedecorators").
		Name(name).
		VersionedParams(&options, scheme.ParameterCodec).
		Do().
		Into(result)
	return
}

// List takes label and field selectors, and returns the list of VolumeDecorators that match those selectors.
func (c *volumeDecorators) List(opts metav1.ListOptions) (result *v1.VolumeDecoratorList, err error) {
	var timeout time.Duration
	if opts.TimeoutSeconds != nil {
		timeout = time.Duration(*opts.TimeoutSeconds) * time.Second
	}
	result = &v1.VolumeDecoratorList{}
	err = c.client.Get().
		Resource("volumedecorators").
		VersionedParams(&opts, scheme.ParameterCodec).
		Timeout(timeout).
		Do().
		Into(result)
	return
}

// Watch returns a watch.Interface that watches the requested volumeDecorators.
func (c *volumeDecorators) Watch(opts metav1.ListOptions) (watch.Interface, error) {
	var timeout time.Duration
	if opts.TimeoutSeconds != nil {
		timeout = time.Duration(*opts.TimeoutSeconds) * time.Second
	}
	opts.Watch = true
	return c.client.Get().
		Resource("volumedecorators").
		VersionedParams(&opts, scheme.ParameterCodec).
		Timeout(timeout).
		Watch()
}

// Create takes the representation of a volumeDecorator and creates it.  Returns the server's representation of the volumeDecorator, and an error, if there is any.
func (c *volumeDecorators) Create(volumeDecorator *v1.VolumeDecorator) (result *v1.VolumeDecorator, err error) {
	result = &v1.VolumeDecorator{}
	err = c.client.Post().
		Resource("volumedecorators").
		Body(volumeDecorator).
		Do().
		Into(result)
	return
}

// Update takes the representation of a volumeDecorator and updates it. Returns the server's representation of the volumeDecorator, and an error, if there is any.
func (c *volumeDecorators) Update(volumeDecorator *v1.VolumeDecorator) (result *v1.VolumeDecorator, err error) {
	result = &v1.VolumeDecorator{}
	err = c.client.Put().
		Resource("volumedecorators").
		Name(volumeDecorator.Name).
		Body(volumeDecorator).
		Do().
		Into(result)
	return
}

// UpdateStatus was generated because the type contains a Status member.
// Add a +genclient:noStatus comment above the type to avoid generating UpdateStatus().

func (c *volumeDecorators) UpdateStatus(volumeDecorator *v1.VolumeDecorator) (result *v1.VolumeDecorator, err error) {
	result = &v1.VolumeDecorator{}
	err = c.client.Put().
		Resource("volumedecorators").
		Name(volumeDecorator.Name).
		SubResource("status").
		Body(volumeDecorator).
		Do().
		Into(result)
	return
}

// Delete takes name of the volumeDecorator and deletes it. Returns an error if one occurs.
func (c *volumeDecorators) Delete(name string, options *metav1.DeleteOptions) error {
	return c.client.Delete().
		Resource("volumedecorators").
		Name(name).
		Body(options).
		Do().
		Error()
}

// Patch applies the patch and returns the patched volumeDecorator.
func (c *volumeDecorators) Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *v1.VolumeDecorator, err error) {
	result = &v1.VolumeDecorator{}
	err = c.client.Patch(pt).
		Resource("volumedecorators").
		SubResource(subresources...).
		Name(name).
		Body(data).
		Do().
		Into(result)
	return
}
